@@ -2,7 +2,8 @@ import os
 from investing_algorithm_framework.configuration.settings import Config
 from investing_algorithm_framework.configuration.validator import \
     ConfigValidator
-from investing_algorithm_framework.configuration.setup import create_app
+from investing_algorithm_framework.configuration.setup import create_app, \
+    setup_config
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -11,5 +12,6 @@ __all__ = [
     "Config",
     "BASE_DIR",
     "ConfigValidator",
-    "create_app"
+    "create_app",
+    "setup_config"
 ]
